Class: Snoot::RenderReport::Report

Inherits:
Data
  • Object
show all
Defined in:
lib/snoot/render_report.rb

Overview

Report is the value returned by RenderReport.invoke: the source Run, the selected Finding it was built from, and the ordered sections hash that CLI joins into stdout output.

Instance Attribute Summary collapse

Instance Attribute Details

#findingObject (readonly)

Returns the value of attribute finding

Returns:

  • (Object)

    the current value of finding



12
13
14
# File 'lib/snoot/render_report.rb', line 12

def finding
  @finding
end

#runObject (readonly)

Returns the value of attribute run

Returns:

  • (Object)

    the current value of run



12
13
14
# File 'lib/snoot/render_report.rb', line 12

def run
  @run
end

#sectionsObject (readonly)

Returns the value of attribute sections

Returns:

  • (Object)

    the current value of sections



12
13
14
# File 'lib/snoot/render_report.rb', line 12

def sections
  @sections
end