Class: Snoot::RenderReport::Report
- Inherits:
-
Data
- Object
- Data
- Snoot::RenderReport::Report
- Defined in:
- lib/snoot/render_report.rb
Overview
Report is the value returned by RenderReport.invoke: the source Run, the selected Finding it was built from, and the ordered sections hash that CLI joins into stdout output.
Instance Attribute Summary collapse
-
#finding ⇒ Object
readonly
Returns the value of attribute finding.
-
#run ⇒ Object
readonly
Returns the value of attribute run.
-
#sections ⇒ Object
readonly
Returns the value of attribute sections.
Instance Attribute Details
#finding ⇒ Object (readonly)
Returns the value of attribute finding
12 13 14 |
# File 'lib/snoot/render_report.rb', line 12 def finding @finding end |
#run ⇒ Object (readonly)
Returns the value of attribute run
12 13 14 |
# File 'lib/snoot/render_report.rb', line 12 def run @run end |
#sections ⇒ Object (readonly)
Returns the value of attribute sections
12 13 14 |
# File 'lib/snoot/render_report.rb', line 12 def sections @sections end |